#
# spec file for package libdbi
#
# Copyright (c) 2019 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global flavor %nil

%global sname libdbi
%if "%flavor" == "devel-doc"
%global psuffix -devel-doc
%endif

Name:           libdbi%{?psuffix}
%define lname	libdbi3
Version:        0.9.0.g33
#Snapshot:	libdbi-0.9.0-33-gcdc4479
Release:        4.14
%if "%flavor" == ""
Summary:        Database Independent Abstraction Layer for C
Group:          Development/Libraries/C and C++
%endif
License:        LGPL-2.1-or-later
URL:            http://libdbi.sourceforge.net/

#Git-Clone:	git://git.code.sf.net/p/libdbi/libdbi
#Source:         http://downloads.sf.net/libdbi/%%name-%%version.tar.gz
Source:         %sname-%version.tar.xz
Source2:        baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
%if "%flavor" == "devel-doc"
# Only needed when doc is not already prebuilt
BuildRequires:  docbook-dsssl-stylesheets
BuildRequires:  openjade
BuildRequires:  tex(8r.enc)
BuildRequires:  tex(t1ptm.fd)
BuildRequires:  tex(t1phv.fd)
BuildRequires:  tex(uwasy.fd)
BuildRequires:  tex(wasy10.tfm)
BuildRequires:  texlive-jadetex
BuildRequires:  texlive-pdftex-bin
Provides:       libdbi-devel:%_docdir/libdbi/driver-guide.pdf
%endif

%if "%flavor" == ""
%description
libdbi implements a database-independent abstraction layer in C,
similar to the DBI/DBD layer in Perl. Writing one generic set of
code, programmers can leverage the power of multiple databases and
multiple simultaneous database connections by using this framework.

%else
Summary:        Development documentation for libdbi
Group:          Documentation/Other
BuildArch:      noarch

%description
The libdbi-devel-doc package contains libdbi programmers-guide
and driver-guide.
%endif

%package -n %lname
Summary:        Database Independent Abstraction Layer for C
Group:          System/Libraries

%description -n %lname
libdbi implements a database-independent abstraction layer in C,
similar to the DBI/DBD layer in Perl. Writing one generic set of
code, programmers can leverage the power of multiple databases and
multiple simultaneous database connections by using this framework.

%package devel
Summary:        Development files for libdbi (Database Independent Abstraction Layer for C)
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The libdbi-devel package contains the header files needed to develop
applications with libdbi.


%prep
%setup -qn %sname

%build
autoreconf -fi
sed -i s,\-O20,\-O2,g configure
%configure \
%if "%flavor" == ""
	--disable-docs \
%else
	--enable-docs \
%endif
	--docdir="%_docdir/libdbi" \
	--disable-static

%if "%flavor" == ""
%make_build
%else
%make_build -C doc
%endif

%install
%if "%flavor" == ""
%make_install
rm "%buildroot/%_libdir/libdbi.la"

%else
%make_install -C doc
%endif


%if "%flavor" == ""
%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%doc AUTHORS ChangeLog README
%license COPYING
%_libdir/libdbi.so.3*

%files devel
%_includedir/dbi/
%_libdir/libdbi.so
%_libdir/pkgconfig/dbi.pc

%else

%files -n %sname-devel-doc
%dir %_docdir/libdbi
%_docdir/libdbi/*-guide*

%endif

%changelog
* Tue Sep 15 2020 Jan Engelhardt <jengelh@inai.de>
- Trim Recommends. Headers are not semi-essential functionality to
  view documentation.
* Mon Sep 23 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use _multibuild for documentation building, move documentation
  out of devel subpackage.
- Spec file cleanup, modernization.
- Streamline texlive BuildRequires.
* Tue Dec 29 2015 lars@linux-schulserver.de
- disable building of documentation on old distributions
* Tue Nov 11 2014 jengelh@inai.de
- Update to git snapshot 0.9.0+git33
  * Fix crash when calling dbi_conn_close() on a valid object with
  a closed connection (e.g. when login failed). [boo#904873]
* Wed Aug 27 2014 jengelh@inai.de
- Update to git snapshot 0.9.0+git32
  * dbi: an unintialized variable (rightfully flagged by valgrind)
  was fixed
* Mon Jun 30 2014 jengelh@inai.de
- Update to git snapshot 0.9.0+git30
  * dbi: make a distinction between SQL strings and decimals
  (add new type DBI_TYPE_XDECIMAL)
* Thu May  8 2014 jengelh@inai.de
- Update to git snapshot 0.9.0+git27
  * dbi: resolve bogus seeking into dbd
* Thu Apr 17 2014 jengelh@inai.de
- Update to git snapshot 0.9.0+git23
  * api: offer DATETIME fields also as a "struct tm"
* Tue Sep  3 2013 jengelh@inai.de
- Update to new upstream release 0.9.0
  * libdbi now supports multiple independent "instances", which
  permit programs to use several dlopen()ed modules which are
  linked against libdbi. Support for transactions and savepoints
  has been added, and drivers now receive additional hints to
  optimize sequential reads from result sets.
- Wrap description at 70 cols
* Mon Sep 24 2012 andreas.stieger@gmx.de
- update to 0.8.4, soname libdbi1
- now using automake 1.10.1
* Thu Dec 15 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Tue Dec 13 2011 idonmez@suse.com
- Optimization level 20 doesn't really exist, fix it to -O3
- Fix license to be LGPL-2.1+
* Fri Sep 16 2011 jengelh@medozas.de
- Add baselibs configuration
* Wed Dec 15 2010 meissner@suse.de
- cleanup, use RPM_OPT_FLAGS, --disable-static, no .la files
* Wed Dec 15 2010 meissner@suse.de
- initial import if libdbi, a database-independent abstraction layer in C,
  similar to the DBI/DBD layer in Perl.
